package com.unis.quality.server.controller;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.vo.EquipmentVO;
import com.unis.quality.server.service.EquipmentService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * @Description: 质检机构管理--设备信息
 * @ClassName: EquipmentController
 * @author lfx
 * @date 2018年10月30日15:01:24
 * 
 * @version v1.0
 */
@RestController
@Api(value = "质检机构管理--设备信息", tags = "质检机构管理--设备信息")
public class EquipmentController {

	@Autowired
	private EquipmentService equipmentService;
	

	/**
	 * @Description 根据id查询设备信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日14:17:21
	 * @param id
	 * @return ResponseWrapper
	 * @throws
	 */
	@ApiOperation(value = "根据id查询设备信息", notes = "参数：organizationId")
	@GetMapping(value = "/findByIdEquipment/{organizationId}")
	public ResponseWrapper findByIdEquipment(@PathVariable("organizationId") String organizationId)  throws Exception{
		List<EquipmentVO> list = equipmentService.findByIdAndIsDeleted(organizationId);
		return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                list);
	}

	/**
	 * @Description 保存信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:43:55
	 * @param EquipmentVO
	 * @return ResponseWrapper
	 * @throws Exception
	 */
	@ApiOperation(value = "保存设备信息", notes = "参数：设备信息对象equipmentVO")
	@PostMapping(value = "/saveEquipment")
	public ResponseWrapper saveEquipment(@RequestBody EquipmentVO vo) throws Exception {
		boolean flag = equipmentService.save(vo.getEquipmentList(),vo);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "该设备名称已存在无法添加");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
	}

	/**
	 * @Description 更新设备信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:45:49
	 * @param EquipmentVO
	 * @return ResponseWrapper
	 * @throws Exception
	 */
	@ApiOperation(value = "更新设备信息", notes = "参数：设备信息对象equipmentVO")
	@PostMapping(value = "/updateEquipment")
	public ResponseWrapper updateEquipment(@RequestBody EquipmentVO vo) throws Exception{
		boolean flag = equipmentService.update(vo.getEquipmentList(),vo);
		 if (!flag) {
	            return ResponseWrapper.error(
	                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
	                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
	                    "更新失败");
	        }
	        return  ResponseWrapper.success(
	                HttpStatus.OK.value(),
	                HttpStatus.OK.getReasonPhrase(),
	                null);
	}

	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018年10月30日10:41:56
	 * @return ResponseWrapper
	 * @throws Exception
	 */
	@ApiOperation(value = "删除设备信息", notes = "参数：organizationId(可传入多个)")
	@PostMapping(value = "/deleteEquipment")
	public ResponseWrapper deleteEquipment(@RequestBody EquipmentVO vo) throws Exception{
	 	 Boolean flag = equipmentService.deletes(vo.getOrganizationIds(),vo);
		 if (!flag) {
	            return ResponseWrapper.error(
	                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
	                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
	                    "删除设备失败");
	        }
	        return  ResponseWrapper.success(
	                HttpStatus.OK.value(),
	                HttpStatus.OK.getReasonPhrase(),
	                null);
	}


	/**
	 * @Description 查询设备信息、分页
	 * @version v1.0
	 * @author lfx
	 * @param EquipmentVO
	 * @param page
	 * @param size
	 * @date 2018年10月30日15:01:37
	 * @return ResponseWrapper
	 * @throws Exception
	 */
	@ApiOperation(value = "查询所有设备信息", notes = "参数：当前页、页面大小")
	@ApiImplicitParams({ 
		@ApiImplicitParam(name = "page", value = "起始页", required = true),
		@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
	@PostMapping(value = "/findByPageEquipment/{page}/{size}")
	public ResponseWrapper findByPageEquipment(@RequestBody EquipmentVO equipmentVO,
			@PathVariable Integer page,
			@PathVariable Integer size) throws Exception{
		Map<String, Object> result = equipmentService.findByPage(equipmentVO, page, size);
		return ResponseWrapper.success(
	                HttpStatus.OK.value(),
	                HttpStatus.OK.getReasonPhrase(),
	                result);
	}
	
	
	
	
	/**
	 * @Author lidiaoquan
	 * @version V1.0
	 * @Description 同步base-server中的设备--检验化验仪器设备
	 * @Date 2020年3月10日 下午3:47:24
	 * @param requestWrapper
	 * @return ResponseWrapper
	 */
	@PostMapping(value = "/synBaseServerEquipment")
	public ResponseWrapper synBaseServerEquipment(@RequestBody ResponseWrapper requestWrapper) {
    	JSONArray contentJsonArr = JSONObject.parseArray(JsonUtils.serialize(requestWrapper.getData()));
    	boolean result = false;
    	try {
			if(contentJsonArr != null && contentJsonArr.size() > 0) {
				result = equipmentService.synBaseServerEquipment(contentJsonArr);
			}
		} catch (Exception e) {
			ResponseWrapper.error("同步设备异常");
			e.printStackTrace();
		}
		return ResponseWrapper.success(result);
	}
}
